"""The `mailjet_rest.utils` package provides utility functions for interacting with the package versionI.

This package includes a module for managing the package version.

Modules:
    - version: Manages the package versioning.
"""
